ete2.clustering.stats.Dispatch

Package ete2 :: Package clustering :: Module stats :: Class Dispatch |
[hide private]
[frames] | no frames]

# Class Dispatch

source code

The Dispatch class, care of David Ascher, allows different functions to be called depending on the argument types. This way, there can be one function name regardless of the argument type. To access function doc in stats.py module, prefix the function with an 'l' or 'a' for list or array arguments, respectively. That is, print stats.lmean.__doc__ or print stats.amean.__doc__ or whatever.

Instance Methods | [hide private]
__init__(self, *tuples) | source code
__call__(self, arg1, *args, **kw) | source code